<?php


namespace PB\SolvedQuestionPrefix\Job;


use XF;
use XF\App;
use XF\Job\AbstractRebuildJob;

class ThreadPrefixRebuild extends AbstractRebuildJob
{
	protected $defaultData = [
		'node_ids' => [],
	];

	protected $nodeIds = [];

	public function __construct(App $app, $jobId, array $data = [])
	{
		parent::__construct($app, $jobId, $data);

		$this->nodeIds = $this->data['node_ids'];

		return null;
	}

	protected function getNextIds($start, $batch)
	{
		$db = $this->app->db();

		$nodeParams = '';
		if ($nodeIds = $this->nodeIds)
		{
			$nodeIds = $db->quote(implode(',', $nodeIds));
			$nodeParams = " AND node_id IN ($nodeIds)";
		}

		return $db->fetchAllColumn($db->limit(
			"
				SELECT thread.thread_id
				FROM xf_thread AS thread
				INNER JOIN xf_thread_question as question
					ON (thread.thread_id = question.thread_id)	
				WHERE thread.thread_id > ? $nodeParams
				ORDER BY node_id
			", $batch
		), [$start]);
	}

	protected function rebuildById($id)
	{
		/** @var \XF\Entity\Thread $thread */
		$thread = $this->app->em()->find('XF:Thread', $id);
		$typeHandler = $thread->getTypeHandler();

		if ($typeHandler instanceof \XF\ThreadType\Question)
		{
			/** @var \PB\SolvedQuestionPrefix\XF\Service\ThreadQuestion\MarkSolution $markSolution */
			$markSolution = $this->app->service('XF:ThreadQuestion\MarkSolution', $thread);

			if ($thread->type_data['solution_post_id'])
			{
				$markSolution->setSolutionPrefix();
			}
		}
	}

	public function getStatusType()
	{
		return XF::phrase('mark_as_solution...');
	}

	public function canCancel()
	{
		return true;
	}

	public function canTriggerByChoice()
	{
		return true;
	}
}
