<?php

namespace PB\SolvedQuestionPrefix\XF\ForumType;

use XF\Api\Result\EntityResult;
use XF\Entity\Forum;
use XF\Entity\Node;
use XF\Http\Request;
use XF\Mvc\Entity\Entity;
use XF\Mvc\FormAction;

class Question extends XFCP_Question
{
	public function getDefaultTypeConfig(): array
	{
		$config = parent::getDefaultTypeConfig();
		$config['pb_sqp_prefix_id'] = 0;
		$config['pb_sqp_remove_prefix_ids'] = [];
		return $config;
	}

	protected function getTypeConfigColumnDefinitions(): array
	{
		$columnDefinitions = parent::getTypeConfigColumnDefinitions();
		$columnDefinitions['pb_sqp_prefix_id'] = ['type' => Entity::UINT];
		$columnDefinitions['pb_sqp_remove_prefix_ids'] = ['type' => Entity::LIST_COMMA];
		return $columnDefinitions;
	}

	public function setupTypeConfigSave(FormAction $form, Node $node, Forum $forum, Request $request)
	{
		$validator = parent::setupTypeConfigSave($form, $node, $forum, $request);

		$validator->bulkSet([
			'pb_sqp_prefix_id' => $request->filter('type_config.pb_sqp_prefix_id', 'uint'),
			'pb_sqp_remove_prefix_ids' => $request->filter('type_config.pb_sqp_remove_prefix_ids', 'array-uint'),
		]);

		return $validator;
	}

	public function addTypeConfigToApiResult(Forum $forum, EntityResult $result, int $verbosity = Entity::VERBOSITY_NORMAL, array $options = [])
	{
		$result->question['pb_sqp_prefix_id'] = $forum->type_config['pb_sqp_prefix_id'];
		$result->question['pb_sqp_remove_prefix_ids'] = $forum->type_config['pb_sqp_remove_prefix_ids'];
	}
}
