<?php

namespace PB\SolvedQuestionPrefix\XF\Service\ThreadQuestion;

use XF\Entity\Post;

class MarkSolution extends XFCP_MarkSolution
{
	protected function isMultiPrefix()
	{
		$addOns = $this->app->container('addon.cache');
        return !empty($addOns['SV/MultiPrefix']);
	}

	protected function getSolutionPrefixId(): int
	{
		$thread = $this->thread;

		$typeConfig = $thread->Forum->getTypeConfig();

		if (!isset($typeConfig['pb_sqp_prefix_id']))
		{
			return 0;
		}

		return $typeConfig['pb_sqp_prefix_id'];
	}

	public function unmarkSolution()
	{
		parent::unmarkSolution();
		$this->unsetSolutionPrefix();
	}

	public function unsetSolutionPrefix()
	{
		$thread = $this->thread;
		$solutionPrefixId = $this->getSolutionPrefixId();

		/** @var \XF\Service\Thread\Editor $editorService */
		$editorService = $this->service('XF:Thread\Editor', $thread);

		if ($this->isMultiPrefix())
		{
			$prefixIds = $thread->sv_prefix_ids;

			if (in_array($solutionPrefixId, $prefixIds))
			{
				$newPrefixIds = [];
				foreach ($prefixIds AS $key => $prefixId)
				{
					if ($prefixId === $solutionPrefixId)
						continue;
					$newPrefixIds[] = $prefixId;
				}

				$editorService->setPrefix($newPrefixIds);
				$editorService->save();
			}
		}
		else
		{
			if ($thread->prefix_id == $solutionPrefixId)
			{
				$editorService->setPrefix(0);
				$editorService->save();
			}
		}
	}

	public function markSolution(Post $post)
	{
		parent::markSolution($post);
		$this->setSolutionPrefix();
	}

	public function setSolutionPrefix()
	{
		$thread = $this->thread;
		$solutionPrefixId = $this->getSolutionPrefixId();

		/** @var \XF\Service\Thread\Editor $editorService */
		$editorService = $this->service('XF:Thread\Editor', $thread);

		if ($this->isMultiPrefix())
		{
			$prefixIds = $thread->sv_prefix_ids;

			if (!in_array($solutionPrefixId, $prefixIds))
			{
				$prefixIds[] = $solutionPrefixId;
			}

			if (isset($typeConfig['pb_sqp_remove_prefix_ids']) && $prefixesToRemove = $typeConfig['pb_sqp_remove_prefix_ids'])
			{
				foreach ($prefixIds AS $key => $prefixId)
				{
					if (in_array($prefixId, $prefixesToRemove))
						unset($prefixIds[$key]);
				}
			}

			$editorService->setPrefix($prefixIds);

			if ($editorService->getThread()->hasChanges())
			{
				$editorService->save();
			}
		}
		else
		{
			if ($thread->prefix_id != $solutionPrefixId)
			{
				$editorService->setPrefix($solutionPrefixId);
				$editorService->save();
			}
		}
	}
}

